@@ -202,8 +202,6 @@ class TreeAdmin(admin.ModelAdmin):
         the object's depth in the hierarchy.
         """
         r = ''
-        if hasattr(item, 'get_absolute_url'):
-            r = '<input type="hidden" class="medialibrary_file_path" value="%s" />' % item.get_absolute_url()
 
         editable_class = ''
         if not getattr(item, 'feincms_editable', True):
@@ -437,4 +435,4 @@ class JohnnyCacheAwareTreeAdmin(TreeAdmin):
         finally:
             johnny.settings.BLACKLIST = original_blacklist
         johnny.cache.invalidate(self.model)
-        return result
\ No newline at end of file
+        return result
